Download PySkein — PySkein v0.5.2 documentation

### Navigation

- index
- previous |
- PySkein v0.5.2 documentation »

# Download PySkein

Source distribution: pyskein-0.5.2.tar.gz (sig)

Windows installer (only for Python 3.1): pyskein-0.5.2.win32-py3.1.msi (sig)

Notes about previous versions:

- If you have a version of PySkein <0.5 installed, please make sure to manually delete “skein.*” from your Python “site-packages” directory before installation!
- All versions of PySkein <0.5 compute Skein hashes according to an older specification of Skein (version 1.1). Starting with PySkein 0.5, hashes are computed according to the current and incompatible specification (version 1.2).

## Changes

0.5.2
  - Release the GIL to allow multiple threads to hash in parallel on multi-core systems
0.5.1
  - Fixed reference leak when changing tweak value on threefish object
0.5
  - Updated rotation constants to new Skein specification (version 1.2)
  - Added implementation of Skein PRNG
0.4
  - Hashing with personalization string
  - Hashing with nonce value
0.3.1
  - Improved demo script “threefish”
  - Better compatibility with Python 3.1
0.3
  - Threefish block decryption
  - Demo scripts “skeinsum” and “threefish”
0.2
  - Support for message authentication codes
  - Threefish block encryption (but no decryption)
  - Fixed one or two reference leaks
0.1
  - Skein-256, Skein-512, and Skein-1024 hashing

## Previous versions

- pyskein-0.5.1.tar.gz (sig)
- pyskein-0.5.tar.gz (sig)
- pyskein-0.4.tar.gz (sig)
- pyskein-0.4.win32-py3.1.exe (sig)
- pyskein-0.3.1.tar.gz (sig)
- pyskein-0.3.tar.gz (sig)
- pyskein-0.2.tar.gz (sig)
- pyskein-0.1.tar.gz (sig)

### Navigation

- index
- previous |
- PySkein v0.5.2 documentation »